Module v1_0_3
redfish_
codegen
0.3.1
Module v1_0_3
Module Items
Structs
Enums
In redfish_
codegen::
models::
acceleration_
function
redfish_codegen
::
models
::
acceleration_function
Module
v1_0_3
Structs

Acceleration
Function
The AccelerationFunction schema describes an acceleration function that a processor implements. This can include functions such as audio processing, compression, encryption, packet inspection, packet switching, scheduling, or video processing.
Actions
The available actions for this Resource.
Links
The links to other Resources that are related to this Resource.
OemActions
The available OEM-specific actions for this Resource.
Enums

Acceleration
Function
Type