Module v1_2_2

Module v1_2_2 

Structs

ASNumberRange
Autonomous System (AS) number range.
Actions
The available actions for this resource.
AddressPool
The schema definition of an address pool and its configuration.
BFDSingleHopOnly
Bidirectional Forwarding Detection (BFD) related properties for an Ethernet fabric.
BGPEvpn
BGP Ethernet Virtual Private Network (BGP EVPN) related properties for an Ethernet fabric.
BGPNeighbor
Border Gateway Protocol (BGP) neighbor related properties.
BGPRoute
Border Gateway Protocol (BGP) route properties.
CommonBGPProperties
Common BGP properties.
DHCP
DHCP related properties for an Ethernet fabric.
EBGP
External BGP (eBGP) related properties for an Ethernet fabric.
ESINumberRange
The Ethernet Segment Identifier (ESI) number range for an Ethernet fabric.
EVINumberRange
The Ethernet Virtual Private Network (EVPN) Instance (EVI) number range for an Ethernet fabric.
Ethernet
Ethernet related properties for an address pool.
GatewayIPAddressRange
The IPv4 address range for gateway nodes for Ethernet Virtual Private Network (EVPN) based fabrics.
GenZ
Gen-Z related properties for an address pool.
GracefulRestart
Border Gateway Protocol (BGP) graceful restart properties.
IPv4
IPv4 and Virtual LAN (VLAN) related addressing for an Ethernet fabric.
IPv4AddressRange
IPv4 related address range for an Ethernet fabric.
Links
The links to other resources that are related to this resource.
MaxPrefix
Border Gateway Protocol (BGP) max prefix properties.
MultiplePaths
Border Gateway Protocol (BGP) multiple path properties.
OemActions
The available OEM-specific actions for this resource.
RouteDistinguisherRange
The Route Distinguisher (RD) number range for an Ethernet fabric.
RouteTargetRange
The Route Target (RT) number range for the fabric.
SystemMACRange
The Media Access Control (MAC) address range for the EVPN based fabrics.
VLANIdentifierAddressRange
VLAN tag related addressing for an Ethernet fabric or for end host networks.