pub struct AddressPool {Show 13 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub description: Option<Description>,
pub ethernet: Option<Ethernet>,
pub gen_z: Option<GenZ>,
pub id: Id,
pub links: Option<Links>,
pub name: Name,
pub oem: Option<Oem>,
pub status: Option<Status>,
}Expand description
The schema definition of an address pool and its configuration.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>description: Option<Description>ethernet: Option<Ethernet>gen_z: Option<GenZ>id: Idlinks: Option<Links>name: Nameoem: Option<Oem>status: Option<Status>Trait Implementations
Sourceimpl Clone for AddressPool
impl Clone for AddressPool
Sourcefn clone(&self) -> AddressPool
fn clone(&self) -> AddressPool
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AddressPool
impl Debug for AddressPool
Sourceimpl Default for AddressPool
impl Default for AddressPool
Sourceimpl<'de> Deserialize<'de> for AddressPool
impl<'de> Deserialize<'de> for AddressPool
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for AddressPool
impl Metadata<'static> for AddressPool
Sourceconst JSON_SCHEMA: &'static str = "AddressPool.v1_2_2.json"
const JSON_SCHEMA: &'static str = "AddressPool.v1_2_2.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.