pub struct IPv4 {Show 19 fields
pub anycast_gateway_ip_address: Option<String>,
pub anycast_gateway_mac_address: Option<String>,
pub dhcp: Option<DHCP>,
pub dns_domain_name: Option<String>,
pub dns_server: Option<Vec<String>>,
pub distribute_into_underlay_enabled: Option<bool>,
pub ebgp_address_range: Option<IPv4AddressRange>,
pub fabric_link_address_range: Option<IPv4AddressRange>,
pub gateway_ip_address: Option<String>,
pub host_address_range: Option<IPv4AddressRange>,
pub ibgp_address_range: Option<IPv4AddressRange>,
pub loopback_address_range: Option<IPv4AddressRange>,
pub management_address_range: Option<IPv4AddressRange>,
pub ntp_offset_hours_minutes: Option<i64>,
pub ntp_server: Option<Vec<String>>,
pub ntp_timezone: Option<String>,
pub native_vlan: Option<i64>,
pub system_mac_range: Option<SystemMACRange>,
pub vlan_identifier_address_range: Option<VLANIdentifierAddressRange>,
}Expand description
IPv4 and Virtual LAN (VLAN) related addressing for an Ethernet fabric.
Fields
anycast_gateway_ip_address: Option<String>The anycast gateway IPv4 address.
anycast_gateway_mac_address: Option<String>The anycast gateway MAC address.
dhcp: Option<DHCP>dns_domain_name: Option<String>The Domain Name Service (DNS) domain name for this Ethernet fabric.
dns_server: Option<Vec<String>>The Domain Name Service (DNS) servers for this Ethernet fabric.
distribute_into_underlay_enabled: Option<bool>Indicates if host subnets should be distributed into the fabric underlay.
ebgp_address_range: Option<IPv4AddressRange>fabric_link_address_range: Option<IPv4AddressRange>gateway_ip_address: Option<String>The gateway IPv4 address.
host_address_range: Option<IPv4AddressRange>ibgp_address_range: Option<IPv4AddressRange>loopback_address_range: Option<IPv4AddressRange>management_address_range: Option<IPv4AddressRange>ntp_offset_hours_minutes: Option<i64>The Network Time Protocol (NTP) offset configuration.
ntp_server: Option<Vec<String>>The Network Time Protocol (NTP) servers for this Ethernet fabric.
ntp_timezone: Option<String>The Network Time Protocol (NTP) timezone for this Ethernet fabric.
native_vlan: Option<i64>The untagged Virtual LAN (VLAN) ID value.
system_mac_range: Option<SystemMACRange>vlan_identifier_address_range: Option<VLANIdentifierAddressRange>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for IPv4
impl<'de> Deserialize<'de> for IPv4
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for IPv4
impl Metadata<'static> for IPv4
Sourceconst JSON_SCHEMA: &'static str = "AddressPool.v1_2_2.json"
const JSON_SCHEMA: &'static str = "AddressPool.v1_2_2.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.