CableStatus

Enum CableStatus 

pub enum CableStatus {
    Normal,
    Degraded,
    Failed,
    Testing,
    Disabled,
    SetByService,
}

Variants



Normal

This value shall indicate the cable is operating normally. The State property in Status shall contain the value Enabled and The Health property in Status shall contain the value OK.



Degraded

This value shall indicate the cable is degraded. The State property in Status shall contain the value Enabled and The Health property in Status shall contain the value Warning.



Failed

This value shall indicate the cable has failed. The State property in Status shall contain the value Enabled and The Health property in Status shall contain the value Critical.



Testing

This value shall indicate the cable is under test. The State property in Status shall contain the value InTest.



Disabled

This value shall indicate the cable is disabled. The State property in Status shall contain the value Disabled.



SetByService

This value shall indicate the status for the cable is not defined by the user. If implemented, the service shall determine the value of the State and Health properties in Status.