pub struct RekeyResponse {
pub csr_string: String,
pub certificate: IdRef,
}Expand description
The response body for the Rekey action.
Fields
csr_string: StringThe string for the certificate signing request.
certificate: IdRefTrait Implementations
Sourceimpl Clone for RekeyResponse
impl Clone for RekeyResponse
Sourcefn clone(&self) -> RekeyResponse
fn clone(&self) -> RekeyResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RekeyResponse
impl Debug for RekeyResponse
Sourceimpl Default for RekeyResponse
impl Default for RekeyResponse
Sourceimpl<'de> Deserialize<'de> for RekeyResponse
impl<'de> Deserialize<'de> for RekeyResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for RekeyResponse
impl Metadata<'static> for RekeyResponse
Sourceconst JSON_SCHEMA: &'static str = "Certificate.v1_7_0.json"
const JSON_SCHEMA: &'static str = "Certificate.v1_7_0.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.