pub struct Chassis {Show 61 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub assembly: Option<IdRef>,
pub asset_tag: Option<String>,
pub certificates: Option<IdRef>,
pub chassis_type: ChassisType,
pub controls: Option<IdRef>,
pub depth_mm: Option<f64>,
pub description: Option<Description>,
pub drives: Option<IdRef>,
pub electrical_source_manager_ur_is: Option<Vec<String>>,
pub electrical_source_names: Option<Vec<String>>,
pub environment_metrics: Option<IdRef>,
pub environmental_class: Option<EnvironmentalClass>,
pub fabric_adapters: Option<IdRef>,
pub height_mm: Option<f64>,
pub hot_pluggable: Option<bool>,
pub id: Id,
pub indicator_led: Option<IndicatorLED>,
pub links: Option<Links>,
pub location: Option<Location>,
pub location_indicator_active: Option<bool>,
pub log_services: Option<IdRef>,
pub manufacturer: Option<String>,
pub max_power_watts: Option<f64>,
pub measurements: Option<Vec<MeasurementBlock>>,
pub media_controllers: Option<IdRef>,
pub memory: Option<IdRef>,
pub memory_domains: Option<IdRef>,
pub min_power_watts: Option<f64>,
pub model: Option<String>,
pub name: Name,
pub network_adapters: Option<IdRef>,
pub oem: Option<Oem>,
pub pcie_devices: Option<IdRef>,
pub pcie_slots: Option<IdRef>,
pub part_number: Option<String>,
pub physical_security: Option<PhysicalSecurity>,
pub power: Option<IdRef>,
pub power_state: Option<PowerState>,
pub power_subsystem: Option<IdRef>,
pub powered_by_parent: Option<bool>,
pub processors: Option<IdRef>,
pub replaceable: Option<bool>,
pub sku: Option<String>,
pub sensors: Option<IdRef>,
pub serial_number: Option<String>,
pub spare_part_number: Option<String>,
pub status: Option<Status>,
pub thermal: Option<IdRef>,
pub thermal_direction: Option<ThermalDirection>,
pub thermal_managed_by_parent: Option<bool>,
pub thermal_subsystem: Option<IdRef>,
pub trusted_components: Option<IdRef>,
pub uuid: Option<UUID>,
pub version: Option<String>,
pub weight_kg: Option<f64>,
pub width_mm: Option<f64>,
}Expand description
The Chassis schema represents the physical components of a system. This resource represents the sheet-metal confined spaces and logical zones such as racks, enclosures, chassis and all other containers. Subsystems, such as sensors, that operate outside of a system’s data plane are linked either directly or indirectly through this resource. A subsystem that operates outside of a system’s data plane are not accessible to software that runs on the system. It also describes the location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource instance with an absent state if a unit is not present.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>assembly: Option<IdRef>asset_tag: Option<String>The user-assigned asset tag of this chassis.
certificates: Option<IdRef>chassis_type: ChassisTypecontrols: Option<IdRef>depth_mm: Option<f64>The depth of the chassis.
description: Option<Description>drives: Option<IdRef>electrical_source_manager_ur_is: Option<Vec<String>>The URIs of the management interfaces for the upstream electrical source connections for this chassis.
electrical_source_names: Option<Vec<String>>The names of the upstream electrical sources, such as circuits or outlets, connected to this chassis.
environment_metrics: Option<IdRef>environmental_class: Option<EnvironmentalClass>fabric_adapters: Option<IdRef>height_mm: Option<f64>The height of the chassis.
hot_pluggable: Option<bool>An indication of whether this component can be inserted or removed while the equipment is in operation.
id: Idindicator_led: Option<IndicatorLED>links: Option<Links>location: Option<Location>location_indicator_active: Option<bool>An indicator allowing an operator to physically locate this resource.
log_services: Option<IdRef>manufacturer: Option<String>The manufacturer of this chassis.
max_power_watts: Option<f64>The upper bound of the total power consumed by the chassis.
measurements: Option<Vec<MeasurementBlock>>An array of DSP0274-defined measurement blocks.
media_controllers: Option<IdRef>memory: Option<IdRef>memory_domains: Option<IdRef>min_power_watts: Option<f64>The lower bound of the total power consumed by the chassis.
model: Option<String>The model number of the chassis.
name: Namenetwork_adapters: Option<IdRef>oem: Option<Oem>pcie_devices: Option<IdRef>pcie_slots: Option<IdRef>part_number: Option<String>The part number of the chassis.
physical_security: Option<PhysicalSecurity>power: Option<IdRef>power_state: Option<PowerState>power_subsystem: Option<IdRef>powered_by_parent: Option<bool>Indicates that the chassis receives power from the containing chassis.
processors: Option<IdRef>replaceable: Option<bool>An indication of whether this component can be independently replaced as allowed by the vendor’s replacement policy.
sku: Option<String>The SKU of the chassis.
sensors: Option<IdRef>serial_number: Option<String>The serial number of the chassis.
spare_part_number: Option<String>The spare part number of the chassis.
status: Option<Status>thermal: Option<IdRef>thermal_direction: Option<ThermalDirection>thermal_managed_by_parent: Option<bool>Indicates that the chassis is thermally managed by the parent chassis.
thermal_subsystem: Option<IdRef>trusted_components: Option<IdRef>uuid: Option<UUID>version: Option<String>The hardware version of this chassis.
weight_kg: Option<f64>The weight of the chassis.
width_mm: Option<f64>The width of the chassis.