ProvisioningPolicy

Enum ProvisioningPolicy 

pub enum ProvisioningPolicy {
    Fixed,
    Thin,
}
Space provisioning policy.

Variants



Fixed

This enumeration literal specifies storage shall be fully allocated.



Thin

This enumeration literal specifies storage may be over allocated.