pub enum StatusIndicator {
OK,
Fail,
Rebuild,
PredictiveFailureAnalysis,
Hotspare,
InACriticalArray,
InAFailedArray,
}Variants
OK
The drive is OK.
Fail
The drive has failed.
Rebuild
The drive is being rebuilt.
PredictiveFailureAnalysis
The drive still works but is predicted to fail soon.
Hotspare
The drive has been marked to automatically rebuild and replace a failed drive.
InACriticalArray
The array to which this drive belongs has been degraded.
InAFailedArray
The array to which this drive belongs has failed.