Drive

Struct Drive 

pub struct Drive {
Show 50 fields pub odata_context: Option<Context>, pub odata_etag: Option<Etag>, pub odata_id: Id, pub odata_type: Type, pub actions: Option<Actions>, pub assembly: Option<IdRef>, pub asset_tag: Option<String>, pub block_size_bytes: Option<i64>, pub capable_speed_gbs: Option<f64>, pub capacity_bytes: Option<i64>, pub certificates: Option<IdRef>, pub description: Option<Description>, pub drive_form_factor: Option<FormFactor>, pub encryption_ability: Option<EncryptionAbility>, pub encryption_status: Option<EncryptionStatus>, pub environment_metrics: Option<IdRef>, pub failure_predicted: Option<bool>, pub firmware_version: Option<String>, pub hotspare_replacement_mode: Option<HotspareReplacementModeType>, pub hotspare_type: Option<HotspareType>, pub id: Id, pub identifiers: Option<Vec<Identifier>>, pub indicator_led: Option<IndicatorLED>, pub links: Option<Links>, pub location: Option<Vec<Location>>, pub location_indicator_active: Option<bool>, pub manufacturer: Option<String>, pub measurements: Option<Vec<MeasurementBlock>>, pub media_type: Option<MediaType>, pub metrics: Option<IdRef>, pub model: Option<String>, pub multipath: Option<bool>, pub name: Name, pub negotiated_speed_gbs: Option<f64>, pub oem: Option<Oem>, pub operations: Option<Vec<Operations>>, pub part_number: Option<String>, pub physical_location: Option<Location>, pub predicted_media_life_left_percent: Option<f64>, pub protocol: Option<Protocol>, pub ready_to_remove: Option<bool>, pub revision: Option<String>, pub rotation_speed_rpm: Option<f64>, pub sku: Option<String>, pub serial_number: Option<String>, pub slot_capable_protocols: Option<Vec<Protocol>>, pub slot_form_factor: Option<FormFactor>, pub status: Option<Status>, pub status_indicator: Option<StatusIndicator>, pub write_cache_enabled: Option<bool>,
}
The Drive schema represents a single physical drive for a system, including links to associated volumes. It also describes the location, such as a slot, socket, or bay, where a unit can be installed, by populating a resource instance with an absent state if a unit is not present.

Fields

odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>assembly: Option<IdRef>asset_tag: Option<String>

The user-assigned asset tag for this drive.

block_size_bytes: Option<i64>

The size, in bytes, of the smallest addressable unit, or block.

capable_speed_gbs: Option<f64>

The speed, in gigabit per second (Gbit/s), at which this drive can communicate to a storage controller in ideal conditions.

capacity_bytes: Option<i64>

The size, in bytes, of this drive.

certificates: Option<IdRef>description: Option<Description>drive_form_factor: Option<FormFactor>encryption_ability: Option<EncryptionAbility>encryption_status: Option<EncryptionStatus>environment_metrics: Option<IdRef>failure_predicted: Option<bool>

An indication of whether this drive currently predicts a failure in the near future.

firmware_version: Option<String>

The firmware version for this drive.

hotspare_replacement_mode: Option<HotspareReplacementModeType>hotspare_type: Option<HotspareType>id: Ididentifiers: Option<Vec<Identifier>>

The durable names for the drive.

indicator_led: Option<IndicatorLED>links: Option<Links>location: Option<Vec<Location>>

The location of the drive.

location_indicator_active: Option<bool>

An indicator allowing an operator to physically locate this resource.

manufacturer: Option<String>

The manufacturer of this drive.

measurements: Option<Vec<MeasurementBlock>>

An array of DSP0274-defined measurement blocks.

media_type: Option<MediaType>metrics: Option<IdRef>model: Option<String>

The model number for the drive.

multipath: Option<bool>

An indication of whether the drive is accessible from multiple paths.

name: Namenegotiated_speed_gbs: Option<f64>

The speed, in gigabit per second (Gbit/s), at which this drive currently communicates to the storage controller.

oem: Option<Oem>operations: Option<Vec<Operations>>

The operations currently running on the Drive.

part_number: Option<String>

The part number for this drive.

physical_location: Option<Location>predicted_media_life_left_percent: Option<f64>

The percentage of reads and writes that are predicted to be available for the media.

protocol: Option<Protocol>ready_to_remove: Option<bool>

An indication of whether the drive is prepared by the system for removal.

revision: Option<String>

The revision of this drive. For SCSI-based drives, this is the version of the drive from the ‘Inquiry’ command, which can be the firmware or hardware version. For other types of drives, this is the hardware version.

rotation_speed_rpm: Option<f64>

The rotation speed of this drive, in revolutions per minute (RPM).

sku: Option<String>

The SKU for this drive.

serial_number: Option<String>

The serial number for this drive.

slot_capable_protocols: Option<Vec<Protocol>>

The drive protocols capable in this slot.

slot_form_factor: Option<FormFactor>status: Option<Status>status_indicator: Option<StatusIndicator>write_cache_enabled: Option<bool>

An indication of whether the drive write cache is enabled.