pub struct SecureEraseRequestBody {
pub overwrite_passes: Option<i64>,
pub sanitization_type: Option<DataSanitizationType>,
}Expand description
This action securely erases the contents of the drive.
Fields
overwrite_passes: Option<i64>The number of times to overwrite the drive if performing an overwrite type of sanitization.
sanitization_type: Option<DataSanitizationType>Trait Implementations
Sourceimpl Clone for SecureEraseRequestBody
impl Clone for SecureEraseRequestBody
Sourcefn clone(&self) -> SecureEraseRequestBody
fn clone(&self) -> SecureEraseRequestBody
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecureEraseRequestBody
impl Debug for SecureEraseRequestBody
Sourceimpl Default for SecureEraseRequestBody
impl Default for SecureEraseRequestBody
Sourceimpl<'de> Deserialize<'de> for SecureEraseRequestBody
impl<'de> Deserialize<'de> for SecureEraseRequestBody
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for SecureEraseRequestBody
impl Metadata<'static> for SecureEraseRequestBody
Sourceconst JSON_SCHEMA: &'static str = "Drive.v1_17_0.json"
const JSON_SCHEMA: &'static str = "Drive.v1_17_0.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.