Module v1_8_0

Module v1_8_0 

Structs

Actions
The available actions for this resource.
ConnectedEntity
Represents a remote resource that is connected to the network accessible to this endpoint.
Endpoint
The Endpoint schema contains the properties of an endpoint resource that represents the properties of an entity that sends or receives protocol-defined messages over a transport.
GCID
The Global Component ID (GCID).
GenZ
The Gen-Z related properties for an entity.
IPTransportDetails
This type specifies the details of the transport supported by the endpoint. The properties that are present are dependent on the type of transport supported by the endpoint.
Links
The links to other resources that are related to this resource.
OemActions
The available OEM-specific actions for this resource.
PciId
A PCI ID.

Enums

EntityRole
EntityType