Links

Struct Links 

pub struct Links {
Show 26 fields pub cd_us: Option<Vec<IdRef>>, pub cd_us_odata_count: Option<Count>, pub contained_by_facility: Option<IdRef>, pub contains_chassis: Option<Vec<IdRef>>, pub contains_chassis_odata_count: Option<Count>, pub contains_facilities: Option<Vec<IdRef>>, pub contains_facilities_odata_count: Option<Count>, pub cooling_loops: Option<Vec<IdRef>>, pub cooling_loops_odata_count: Option<Count>, pub electrical_buses: Option<Vec<IdRef>>, pub electrical_buses_odata_count: Option<Count>, pub floor_pd_us: Option<Vec<IdRef>>, pub floor_pd_us_odata_count: Option<Count>, pub immersion_units: Option<Vec<IdRef>>, pub immersion_units_odata_count: Option<Count>, pub managed_by: Option<Vec<IdRef>>, pub managed_by_odata_count: Option<Count>, pub oem: Option<Oem>, pub power_shelves: Option<Vec<IdRef>>, pub power_shelves_odata_count: Option<Count>, pub rack_pd_us: Option<Vec<IdRef>>, pub rack_pd_us_odata_count: Option<Count>, pub switchgear: Option<Vec<IdRef>>, pub switchgear_odata_count: Option<Count>, pub transfer_switches: Option<Vec<IdRef>>, pub transfer_switches_odata_count: Option<Count>,
}
The links to other resources that are related to this resource.

Fields

cd_us: Option<Vec<IdRef>>

An array of links to the cooling distribution units in this facility.

cd_us_odata_count: Option<Count>contained_by_facility: Option<IdRef>contains_chassis: Option<Vec<IdRef>>

An array of links to outermost chassis contained within this facility.

contains_chassis_odata_count: Option<Count>contains_facilities: Option<Vec<IdRef>>

An array of links to other facilities contained within this facility.

contains_facilities_odata_count: Option<Count>cooling_loops: Option<Vec<IdRef>>

An array of links to the cooling loops in this facility.

cooling_loops_odata_count: Option<Count>electrical_buses: Option<Vec<IdRef>>

An array of links to the electrical buses in this facility.

electrical_buses_odata_count: Option<Count>floor_pd_us: Option<Vec<IdRef>>

An array of links to the floor power distribution units in this facility.

floor_pd_us_odata_count: Option<Count>immersion_units: Option<Vec<IdRef>>

An array of links to the immersion cooling units in this facility.

immersion_units_odata_count: Option<Count>managed_by: Option<Vec<IdRef>>

An array of links to the managers responsible for managing this facility.

managed_by_odata_count: Option<Count>oem: Option<Oem>power_shelves: Option<Vec<IdRef>>

An array of links to the power shelves in this facility.

power_shelves_odata_count: Option<Count>rack_pd_us: Option<Vec<IdRef>>

An array of links to the rack-level power distribution units in this facility.

rack_pd_us_odata_count: Option<Count>switchgear: Option<Vec<IdRef>>

An array of links to the switchgear in this facility.

switchgear_odata_count: Option<Count>transfer_switches: Option<Vec<IdRef>>

An array of links to the transfer switches in this facility.

transfer_switches_odata_count: Option<Count>