pub enum AddressState {
Preferred,
Deprecated,
Tentative,
Failed,
}Variants
Preferred
This address is currently within both its RFC4862-defined valid and preferred lifetimes.
Deprecated
This address is currently within its valid lifetime but is now outside its RFC4862-defined preferred lifetime.
Tentative
This address is currently undergoing Duplicate Address Detection (DAD) testing, as defined in RFC4862, section 5.4.
Failed
This address has failed Duplicate Address Detection (DAD) testing, as defined in RFC4862, section 5.4, and is not currently in use.