pub struct KeyPolicy {
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub description: Option<Description>,
pub id: Id,
pub is_default: Option<bool>,
pub key_policy_type: Option<KeyPolicyType>,
pub nvme_of: Option<NVMeoF>,
pub name: Name,
pub oem: Option<Oem>,
}Expand description
The KeyPolicy schema describes settings for how keys are allowed to be used for accessing devices or services.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>description: Option<Description>id: Idis_default: Option<bool>Indicates if this is the default key policy.
key_policy_type: Option<KeyPolicyType>nvme_of: Option<NVMeoF>name: Nameoem: Option<Oem>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for KeyPolicy
impl<'de> Deserialize<'de> for KeyPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for KeyPolicy
impl Metadata<'static> for KeyPolicy
Sourceconst JSON_SCHEMA: &'static str = "KeyPolicy.v1_0_0.json"
const JSON_SCHEMA: &'static str = "KeyPolicy.v1_0_0.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.