Module v1_2_0

Module v1_2_0 

Structs

Actions
The available actions for this resource.
BootTimeStatistics
The boot time statistics of a manager.
I2CBStatistics
The statistics of an I2C bus.
ManagerDiagnosticData
The ManagerDiagnosticData schema defines internal diagnostic data for a manager. It contains information that might be used by vendors to collect debug information about the manager. Clients should not make decisions for raising alerts, creating service events, or other actions based on information in this resource.
MemoryECCStatistics
The memory ECC statistics of a manager.
MemoryStatistics
The memory statistics of a manager.
OemActions
The available OEM-specific actions for this resource.
ProcessStatistics
The statistics of a process running on a manager.
ProcessorStatistics
The processor statistics of a manager.
ResetMetrics
Resets time intervals or counted values of the diagnostic data for this manager.
ResetMetricsRequestBody
Resets time intervals or counted values of the diagnostic data for this manager.