pub struct OutletGroupCollection {
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub description: Option<Description>,
pub members: Vec<IdRef>,
pub members_odata_count: Count,
pub members_odata_next_link: Option<NextLink>,
pub name: Name,
pub oem: Option<Oem>,
}Expand description
The collection of OutletGroup resource instances.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typedescription: Option<Description>members: Vec<IdRef>The members of this collection.
members_odata_count: Countmembers_odata_next_link: Option<NextLink>name: Nameoem: Option<Oem>Trait Implementations
Sourceimpl Clone for OutletGroupCollection
impl Clone for OutletGroupCollection
Sourcefn clone(&self) -> OutletGroupCollection
fn clone(&self) -> OutletGroupCollection
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutletGroupCollection
impl Debug for OutletGroupCollection
Sourceimpl Default for OutletGroupCollection
impl Default for OutletGroupCollection
Sourceimpl<'de> Deserialize<'de> for OutletGroupCollection
impl<'de> Deserialize<'de> for OutletGroupCollection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for OutletGroupCollection
impl Metadata<'static> for OutletGroupCollection
Sourceconst JSON_SCHEMA: &'static str = "OutletGroupCollection.json"
const JSON_SCHEMA: &'static str = "OutletGroupCollection.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.