pub struct OutputRail {
pub nominal_voltage: Option<f64>,
pub physical_context: Option<PhysicalContext>,
}Expand description
This type describes an output power rail for a power supply.
Fields
nominal_voltage: Option<f64>The nominal voltage of this output power rail.
physical_context: Option<PhysicalContext>Trait Implementations
Sourceimpl Clone for OutputRail
impl Clone for OutputRail
Sourcefn clone(&self) -> OutputRail
fn clone(&self) -> OutputRail
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputRail
impl Debug for OutputRail
Sourceimpl Default for OutputRail
impl Default for OutputRail
Sourceimpl<'de> Deserialize<'de> for OutputRail
impl<'de> Deserialize<'de> for OutputRail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Metadata<'static> for OutputRail
impl Metadata<'static> for OutputRail
Sourceconst JSON_SCHEMA: &'static str = "PowerSupply.v1_5_1.json"
const JSON_SCHEMA: &'static str = "PowerSupply.v1_5_1.json"
Name of the json-schema file that describes the entity that implements this trait. Should
be only the file name, so that it can be resolved relative to the URL of the redfish
service, or the public Redfish schema index.