Pump

Struct Pump 

pub struct Pump {
Show 28 fields pub odata_context: Option<Context>, pub odata_etag: Option<Etag>, pub odata_id: Id, pub odata_type: Type, pub actions: Option<Actions>, pub assembly: Option<IdRef>, pub asset_tag: Option<String>, pub description: Option<Description>, pub filters: Option<IdRef>, pub firmware_version: Option<String>, pub id: Id, pub location: Option<Location>, pub location_indicator_active: Option<bool>, pub manufacturer: Option<String>, pub model: Option<String>, pub name: Name, pub oem: Option<Oem>, pub part_number: Option<String>, pub physical_context: Option<PhysicalContext>, pub production_date: Option<String>, pub pump_speed_percent: Option<SensorPumpExcerpt>, pub pump_type: Option<PumpType>, pub serial_number: Option<String>, pub service_hours: Option<f64>, pub spare_part_number: Option<String>, pub status: Option<Status>, pub user_label: Option<String>, pub version: Option<String>,
}
The Pump schema describes a pump unit for a cooling system or similar device.

Fields

odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>assembly: Option<IdRef>asset_tag: Option<String>

The user-assigned asset tag for this equipment.

description: Option<Description>filters: Option<IdRef>firmware_version: Option<String>

The firmware version of this equipment.

id: Idlocation: Option<Location>location_indicator_active: Option<bool>

An indicator allowing an operator to physically locate this resource.

manufacturer: Option<String>

The manufacturer of this pump.

model: Option<String>

The model number for this pump.

name: Nameoem: Option<Oem>part_number: Option<String>

The part number for this pump.

physical_context: Option<PhysicalContext>production_date: Option<String>

The production or manufacturing date of this equipment.

pump_speed_percent: Option<SensorPumpExcerpt>pump_type: Option<PumpType>serial_number: Option<String>

The serial number for this pump.

service_hours: Option<f64>

The hours of service this pump has provided.

spare_part_number: Option<String>

The spare part number for this pump.

status: Option<Status>user_label: Option<String>

A user-assigned label.

version: Option<String>

The hardware version of this equipment.