RegisteredClient

Struct RegisteredClient 

pub struct RegisteredClient {
Show 16 fields pub odata_context: Option<Context>, pub odata_etag: Option<Etag>, pub odata_id: Id, pub odata_type: Type, pub actions: Option<Actions>, pub client_type: ClientType, pub client_uri: Option<String>, pub context: Option<String>, pub created_date: Option<String>, pub description: Option<Description>, pub expiration_date: Option<String>, pub id: Id, pub managed_resources: Option<Vec<ManagedResource>>, pub name: Name, pub oem: Option<Oem>, pub sub_context: Option<String>,
}
The RegisteredClient schema defines the record format for a registered client. It is designed to allow well behaved clients to register with a Redfish service such that other clients are aware the service might be configured or monitored by the client.

Fields

odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>client_type: ClientTypeclient_uri: Option<String>

The URI of the registered client.

context: Option<String>

A client-supplied data for providing context for its own use.

created_date: Option<String>

The date and time when the client entry was created.

description: Option<Description>expiration_date: Option<String>

The date and time when the client entry will expire.

id: Idmanaged_resources: Option<Vec<ManagedResource>>

An array of resources that the registered client monitors or configures.

name: Nameoem: Option<Oem>sub_context: Option<String>

Additional client-supplied data for providing contextual information for its own use.