Module v1_11_4

Module v1_11_4 

Structs

ContactInfo
Contact information for this resource.
Identifier
Any additional identifiers for a resource.
Location
The location of a resource.
PartLocation
The part location for a resource within an enclosure.
Placement
The placement within the addressed location.
PostalAddress
The postal address for a resource.
Resource
The base type for resources and members that can be linked to.

Enums

DurableNameFormat
LocationType
The types of locations for a part within an enclosure.
Orientation
The orientations for the ordering of the part location ordinal value.
RackUnits
The type of rack unit in use.
Reference
The reference areas for the location of the part within an enclosure.