Module v1_4_1

Module v1_4_1 

Structs

Actions
The available actions for this resource.
CompositionStatus
Composition status of the resource block.
Links
The links to other resources that are related to this resource.
OemActions
The available OEM-specific actions for this resource.
ResourceBlock
The ResourceBlock schema contains definitions resource blocks, its components, and affinity to composed devices.

Enums

CompositionState
PoolType
ResourceBlockType