pub enum CompositionState {
Composing,
ComposedAndAvailable,
Composed,
Unused,
Failed,
Unavailable,
}Variants
Composing
Intermediate state indicating composition is in progress.
ComposedAndAvailable
The resource block is currently participating in one or more compositions, and is available to use in more compositions. Added in version v1_1_0.
Composed
Final successful state of a resource block that has participated in composition.
Unused
The resource block is free and can participate in composition.
Failed
The final composition resulted in failure and manual intervention might be required to fix it.
The resource block has been made unavailable by the service, such as due to maintenance being performed on the resource block. Added in version v1_2_0.