CompositionStatus

Struct CompositionStatus 

pub struct CompositionStatus {
    pub composition_state: CompositionState,
    pub max_compositions: Option<i64>,
    pub number_of_compositions: Option<i64>,
    pub reserved: Option<bool>,
    pub sharing_capable: Option<bool>,
    pub sharing_enabled: Option<bool>,
}
Composition status of the resource block.

Fields

composition_state: CompositionStatemax_compositions: Option<i64>

The maximum number of compositions in which this resource block can participate simultaneously.

number_of_compositions: Option<i64>

The number of compositions in which this resource block is currently participating.

reserved: Option<bool>

An indication of whether any client has reserved the resource block.

sharing_capable: Option<bool>

An indication of whether this resource block can participate in multiple compositions simultaneously.

sharing_enabled: Option<bool>

An indication of whether this resource block is allowed to participate in multiple compositions simultaneously.