ResourceBlock

Struct ResourceBlock 

pub struct ResourceBlock {
Show 31 fields pub odata_context: Option<Context>, pub odata_etag: Option<Etag>, pub odata_id: Id, pub odata_type: Type, pub actions: Option<Actions>, pub client: Option<String>, pub composition_status: CompositionStatus, pub computer_systems: Option<Vec<IdRef>>, pub computer_systems_odata_count: Option<Count>, pub description: Option<Description>, pub drives: Option<Vec<IdRef>>, pub drives_odata_count: Option<Count>, pub ethernet_interfaces: Option<Vec<IdRef>>, pub ethernet_interfaces_odata_count: Option<Count>, pub id: Id, pub links: Option<Links>, pub memory: Option<Vec<IdRef>>, pub memory_odata_count: Option<Count>, pub name: Name, pub network_interfaces: Option<Vec<IdRef>>, pub network_interfaces_odata_count: Option<Count>, pub oem: Option<Oem>, pub pool: Option<PoolType>, pub processors: Option<Vec<IdRef>>, pub processors_odata_count: Option<Count>, pub resource_block_type: Vec<ResourceBlockType>, pub simple_storage: Option<Vec<IdRef>>, pub simple_storage_odata_count: Option<Count>, pub status: Option<Status>, pub storage: Option<Vec<IdRef>>, pub storage_odata_count: Option<Count>,
}
The ResourceBlock schema contains definitions resource blocks, its components, and affinity to composed devices.

Fields

odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>client: Option<String>

The client to which this resource block is assigned.

composition_status: CompositionStatuscomputer_systems: Option<Vec<IdRef>>

An array of links to the computer systems available in this resource block.

computer_systems_odata_count: Option<Count>description: Option<Description>drives: Option<Vec<IdRef>>

An array of links to the drives available in this resource block.

drives_odata_count: Option<Count>ethernet_interfaces: Option<Vec<IdRef>>

An array of links to the Ethernet interfaces available in this resource block.

ethernet_interfaces_odata_count: Option<Count>id: Idlinks: Option<Links>memory: Option<Vec<IdRef>>

An array of links to the memory available in this resource block.

memory_odata_count: Option<Count>name: Namenetwork_interfaces: Option<Vec<IdRef>>

An array of links to the Network Interfaces available in this resource block.

network_interfaces_odata_count: Option<Count>oem: Option<Oem>pool: Option<PoolType>processors: Option<Vec<IdRef>>

An array of links to the processors available in this resource block.

processors_odata_count: Option<Count>resource_block_type: Vec<ResourceBlockType>

The types of resources available on this resource block.

simple_storage: Option<Vec<IdRef>>

An array of links to the simple storage available in this resource block.

simple_storage_odata_count: Option<Count>status: Option<Status>storage: Option<Vec<IdRef>>

An array of links to the storage available in this resource block.

storage_odata_count: Option<Count>