pub struct Fan {Show 32 fields
pub odata_id: Id,
pub actions: Option<FanActions>,
pub assembly: Option<IdRef>,
pub fan_name: Option<String>,
pub hot_pluggable: Option<bool>,
pub indicator_led: Option<IndicatorLED>,
pub location: Option<Location>,
pub lower_threshold_critical: Option<i64>,
pub lower_threshold_fatal: Option<i64>,
pub lower_threshold_non_critical: Option<i64>,
pub manufacturer: Option<String>,
pub max_reading_range: Option<i64>,
pub member_id: String,
pub min_reading_range: Option<i64>,
pub model: Option<String>,
pub name: Option<String>,
pub oem: Option<Oem>,
pub part_number: Option<String>,
pub physical_context: Option<PhysicalContext>,
pub reading: Option<i64>,
pub reading_units: Option<ReadingUnits>,
pub redundancy: Option<Vec<Redundancy>>,
pub redundancy_odata_count: Option<Count>,
pub related_item: Option<Vec<IdRef>>,
pub related_item_odata_count: Option<Count>,
pub sensor_number: Option<i64>,
pub serial_number: Option<String>,
pub spare_part_number: Option<String>,
pub status: Option<Status>,
pub upper_threshold_critical: Option<i64>,
pub upper_threshold_fatal: Option<i64>,
pub upper_threshold_non_critical: Option<i64>,
}Fields
odata_id: Idactions: Option<FanActions>assembly: Option<IdRef>fan_name: Option<String>The name of the fan.
hot_pluggable: Option<bool>An indication of whether this device can be inserted or removed while the equipment is in operation.
indicator_led: Option<IndicatorLED>location: Option<Location>lower_threshold_critical: Option<i64>The value at which the reading is below normal range but not yet fatal.
lower_threshold_fatal: Option<i64>The value at which the reading is below normal range and fatal.
lower_threshold_non_critical: Option<i64>The value at which the reading is below normal range.
manufacturer: Option<String>The manufacturer of this fan.
max_reading_range: Option<i64>Maximum value for this sensor.
member_id: StringThe identifier for the member within the collection.
min_reading_range: Option<i64>Minimum value for this sensor.
model: Option<String>The model number for this fan.
name: Option<String>Name of the fan.
oem: Option<Oem>part_number: Option<String>The part number for this fan.
physical_context: Option<PhysicalContext>reading: Option<i64>The fan speed.
reading_units: Option<ReadingUnits>redundancy: Option<Vec<Redundancy>>The set of redundancy groups for this fan.
redundancy_odata_count: Option<Count>An array of links to resources or objects that this fan services.
sensor_number: Option<i64>The numerical identifier for this fan speed sensor.
serial_number: Option<String>The serial number for this fan.
spare_part_number: Option<String>The spare part number for this fan.
status: Option<Status>upper_threshold_critical: Option<i64>The value at which the reading is above normal range but not yet fatal.
upper_threshold_fatal: Option<i64>The value at which the reading is above normal range and fatal.
upper_threshold_non_critical: Option<i64>The value at which the reading is above normal range.