pub struct Temperature {Show 27 fields
pub odata_id: Id,
pub actions: Option<TemperatureActions>,
pub adjusted_max_allowable_operating_value: Option<i64>,
pub adjusted_min_allowable_operating_value: Option<i64>,
pub delta_physical_context: Option<PhysicalContext>,
pub delta_reading_celsius: Option<f64>,
pub lower_threshold_critical: Option<f64>,
pub lower_threshold_fatal: Option<f64>,
pub lower_threshold_non_critical: Option<f64>,
pub lower_threshold_user: Option<i64>,
pub max_allowable_operating_value: Option<i64>,
pub max_reading_range_temp: Option<f64>,
pub member_id: String,
pub min_allowable_operating_value: Option<i64>,
pub min_reading_range_temp: Option<f64>,
pub name: Option<String>,
pub oem: Option<Oem>,
pub physical_context: Option<PhysicalContext>,
pub reading_celsius: Option<f64>,
pub related_item: Option<Vec<IdRef>>,
pub related_item_odata_count: Option<Count>,
pub sensor_number: Option<i64>,
pub status: Option<Status>,
pub upper_threshold_critical: Option<f64>,
pub upper_threshold_fatal: Option<f64>,
pub upper_threshold_non_critical: Option<f64>,
pub upper_threshold_user: Option<i64>,
}Fields
odata_id: Idactions: Option<TemperatureActions>adjusted_max_allowable_operating_value: Option<i64>Adjusted maximum allowable operating temperature for this equipment based on the current environmental conditions present.
adjusted_min_allowable_operating_value: Option<i64>Adjusted minimum allowable operating temperature for this equipment based on the current environmental conditions present.
delta_physical_context: Option<PhysicalContext>delta_reading_celsius: Option<f64>The delta temperature reading.
lower_threshold_critical: Option<f64>The value at which the reading is below normal range but not yet fatal.
lower_threshold_fatal: Option<f64>The value at which the reading is below normal range and fatal.
lower_threshold_non_critical: Option<f64>The value at which the reading is below normal range.
lower_threshold_user: Option<i64>The value at which the reading is below the user-defined range.
max_allowable_operating_value: Option<i64>Maximum allowable operating temperature for this equipment.
max_reading_range_temp: Option<f64>Maximum value for this sensor.
member_id: StringThe identifier for the member within the collection.
min_allowable_operating_value: Option<i64>Minimum allowable operating temperature for this equipment.
min_reading_range_temp: Option<f64>Minimum value for this sensor.
name: Option<String>The temperature sensor name.
oem: Option<Oem>physical_context: Option<PhysicalContext>reading_celsius: Option<f64>The temperature in degrees Celsius.
An array of links to resources or objects that represent areas or devices to which this temperature applies.
sensor_number: Option<i64>The numerical identifier of the temperature sensor.
status: Option<Status>upper_threshold_critical: Option<f64>The value at which the reading is above normal range but not yet fatal.
upper_threshold_fatal: Option<f64>The value at which the reading is above normal range and fatal.
upper_threshold_non_critical: Option<f64>The value at which the reading is above normal range.
upper_threshold_user: Option<i64>The value at which the reading is above the user-defined range.