Module v1_9_0

Module v1_9_0 

Structs

Actions
AssignReplicaTarget
This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
AssignReplicaTargetRequestBody
This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
ChangeRAIDLayout
Request system change the RAID layout of the volume.
ChangeRAIDLayoutRequestBody
Request system change the RAID layout of the volume.
CheckConsistency
This action is used to force a check of the Volume’s parity or redundant data to ensure it matches calculated values.
CheckConsistencyRequestBody
This action is used to force a check of the Volume’s parity or redundant data to ensure it matches calculated values.
CreateReplicaTarget
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
CreateReplicaTargetRequestBody
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
ForceEnable
Request system force the volume to an enabled state regardless of data loss.
ForceEnableRequestBody
Request system force the volume to an enabled state regardless of data loss.
Initialize
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
InitializeRequestBody
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
LBAFormat
Links
Add ability to manage spare capacity.
NVMeNamespaceProperties
This contains properties to use when Volume is used to describe an NVMe Namespace.
NamespaceFeatures
OemActions
Operation
RemoveReplicaRelationship
This action is used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
RemoveReplicaRelationshipRequestBody
This action is used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
ResumeReplication
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
ResumeReplicationRequestBody
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
ReverseReplicationRelationship
This action is used to reverse the replication relationship between a source and target volume.
ReverseReplicationRelationshipRequestBody
This action is used to reverse the replication relationship between a source and target volume.
SplitReplication
This action is used to split the replication relationship and suspend data synchronization between a source and target volume.
SplitReplicationRequestBody
This action is used to split the replication relationship and suspend data synchronization between a source and target volume.
SuspendReplication
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
SuspendReplicationRequestBody
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Volume
Volume contains properties used to describe a volume, virtual disk, LUN, or other logical storage entity for any system.