pub struct ResumeReplication {
pub target: Option<String>,
pub title: Option<String>,
}Expand description
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Fields
target: Option<String>Link to invoke action
title: Option<String>Friendly action name