pub struct SuspendReplicationRequestBody {
pub target_volume: String,
}Expand description
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
Fields
target_volume: StringThe Uri to the existing target volume.