pub struct Volume {Show 57 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub access_capabilities: Option<Vec<StorageAccessCapability>>,
pub actions: Option<Actions>,
pub allocated_pools: Option<IdRef>,
pub block_size_bytes: Option<i64>,
pub capacity: Option<Capacity>,
pub capacity_bytes: Option<i64>,
pub capacity_sources: Option<Vec<CapacitySource>>,
pub capacity_sources_odata_count: Option<Count>,
pub compressed: Option<bool>,
pub connections: Option<Vec<IdRef>>,
pub connections_odata_count: Option<Count>,
pub deduplicated: Option<bool>,
pub description: Option<Description>,
pub display_name: Option<String>,
pub encrypted: Option<bool>,
pub encryption_types: Option<Vec<EncryptionTypes>>,
pub io_perf_mode_enabled: Option<bool>,
pub io_statistics: Option<IOStatistics>,
pub id: Id,
pub identifiers: Option<Vec<Identifier>>,
pub initialize_method: Option<InitializeMethod>,
pub is_boot_capable: Option<bool>,
pub links: Option<Links>,
pub logical_unit_number: Option<i64>,
pub low_space_warning_threshold_percents: Option<Vec<i64>>,
pub manufacturer: Option<String>,
pub max_block_size_bytes: Option<i64>,
pub media_span_count: Option<i64>,
pub metrics: Option<IdRef>,
pub model: Option<String>,
pub nvme_namespace_properties: Option<NVMeNamespaceProperties>,
pub name: Name,
pub oem: Option<Oem>,
pub operations: Option<Vec<Operation>>,
pub optimum_io_size_bytes: Option<i64>,
pub provisioning_policy: Option<ProvisioningPolicy>,
pub raid_type: Option<RAIDType>,
pub read_cache_policy: Option<ReadCachePolicyType>,
pub recoverable_capacity_source_count: Option<i64>,
pub remaining_capacity_percent: Option<i64>,
pub remote_replica_targets: Option<Vec<String>>,
pub replica_info: Option<ReplicaInfo>,
pub replica_targets: Option<Vec<IdRef>>,
pub replica_targets_odata_count: Option<Count>,
pub replication_enabled: Option<bool>,
pub status: Option<Status>,
pub storage_groups: Option<IdRef>,
pub strip_size_bytes: Option<i64>,
pub volume_type: Option<VolumeType>,
pub volume_usage: Option<VolumeUsageType>,
pub write_cache_policy: Option<WriteCachePolicyType>,
pub write_cache_state: Option<WriteCacheStateType>,
pub write_hole_protection_policy: Option<WriteHoleProtectionPolicyType>,
}Expand description
Volume contains properties used to describe a volume, virtual disk, LUN, or other logical storage entity for any system.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeaccess_capabilities: Option<Vec<StorageAccessCapability>>Supported IO access capabilities.
actions: Option<Actions>allocated_pools: Option<IdRef>block_size_bytes: Option<i64>The size of the smallest addressable unit (Block) of this volume in bytes.
capacity: Option<Capacity>capacity_bytes: Option<i64>The size in bytes of this Volume.
capacity_sources: Option<Vec<CapacitySource>>An array of space allocations to this volume.
capacity_sources_odata_count: Option<Count>compressed: Option<bool>Indicator of whether or not the Volume has compression enabled.
connections: Option<Vec<IdRef>>An array of references to Connections that includes this volume.
connections_odata_count: Option<Count>deduplicated: Option<bool>Indicator of whether or not the Volume has deduplication enabled.
description: Option<Description>display_name: Option<String>A user-configurable string to name the volume.
encrypted: Option<bool>Is this Volume encrypted.
encryption_types: Option<Vec<EncryptionTypes>>The types of encryption used by this Volume.
io_perf_mode_enabled: Option<bool>Indicates the IO performance mode setting for the volume.
io_statistics: Option<IOStatistics>id: Ididentifiers: Option<Vec<Identifier>>The Durable names for the volume.
initialize_method: Option<InitializeMethod>is_boot_capable: Option<bool>This property indicates whether or not the Volume contains a boot image and is capable of booting.
links: Option<Links>logical_unit_number: Option<i64>Indicates the host-visible LogicalUnitNumber assigned to this Volume.
low_space_warning_threshold_percents: Option<Vec<i64>>Low space warning.
manufacturer: Option<String>The manufacturer or OEM of this storage volume.
max_block_size_bytes: Option<i64>Max Block size in bytes.
media_span_count: Option<i64>Indicates the number of media elements used per span in the secondary RAID for a hierarchical RAID type.
metrics: Option<IdRef>model: Option<String>The model number for this storage volume.
nvme_namespace_properties: Option<NVMeNamespaceProperties>name: Nameoem: Option<Oem>operations: Option<Vec<Operation>>The operations currently running on the Volume.
optimum_io_size_bytes: Option<i64>The size in bytes of this Volume’s optimum IO size.
provisioning_policy: Option<ProvisioningPolicy>raid_type: Option<RAIDType>read_cache_policy: Option<ReadCachePolicyType>recoverable_capacity_source_count: Option<i64>Current number of capacity source resources that are available as replacements.
remaining_capacity_percent: Option<i64>The percentage of the capacity remaining in the Volume.
remote_replica_targets: Option<Vec<String>>URIs to the resources that are remote target replicas of this source.
replica_info: Option<ReplicaInfo>replica_targets: Option<Vec<IdRef>>The resources that are target replicas of this source.
replica_targets_odata_count: Option<Count>replication_enabled: Option<bool>Indicates whether or not replication is enabled on the volume.
status: Option<Status>storage_groups: Option<IdRef>strip_size_bytes: Option<i64>The number of blocks (bytes) in a strip in a disk array that uses striped data mapping.
volume_type: Option<VolumeType>volume_usage: Option<VolumeUsageType>write_cache_policy: Option<WriteCachePolicyType>write_cache_state: Option<WriteCacheStateType>write_hole_protection_policy: Option<WriteHoleProtectionPolicyType>