Composition

Enum Composition 

pub enum Composition {
Show 13 variants ResourceBlockCompositionStateChanged(String), ResourceBlockNotFound(String), ResourceBlockInvalid(String), ConstrainedResourceAlreadyReserved(String), ResourceBlockStateChanged(String), SpecifiedResourceAlreadyReserved(String, String), UnableToProcessStanzaRequest(String, String), ResourceZoneMembershipChanged(String), ResourceBlockInUse(String), NoResourceMatch(String), EmptyManifest, IncompatibleZone, ResourceBlockChanged(String),
}
This registry defines the messages for composition related events

Variants



ResourceBlockCompositionStateChanged(String)

This message shall be used to indicate that the CompositionState property within the CompositionStatus object of a ResourceBlock has changed.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the ResourceBlock that has changed.



ResourceBlockNotFound(String)

This message shall be used to indicate that the referenced resource block is not found.

Tuple Fields

0: String

The value of this argument shall contain the value of the URI of the resource block that is not found.



ResourceBlockInvalid(String)

This message shall be used to indicate that the Id of a referenced resource block is no longer valid.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the resource block that is no longer valid.



ConstrainedResourceAlreadyReserved(String)

This message shall be used to indicate that the requested resources are already reserved in response to a constrained composition request.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the reservation containing the requested resources.



ResourceBlockStateChanged(String)

This message shall be used to indicate that the State property within the Status object of a ResourceBlock has changed.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the ResourceBlock that has changed.



SpecifiedResourceAlreadyReserved(String, String)

This message shall be used to indicate that a resource block is already reserved in response to a specific composition request.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the resource block that is already reserved.

1: String

The value of this argument shall contain the value of the Id property of the reservation containing the requested resource.



UnableToProcessStanzaRequest(String, String)

This message shall be used to indicate that the manifest provided for the Compose action contains a stanza with Content that could not be processed.

Tuple Fields

0: String

The value of this argument shall contain the value of the RequestType parameter of the Compose action.

1: String

The value of this argument shall contain the value of the Id parameter of the stanza.



ResourceZoneMembershipChanged(String)

This message shall be used to indicate that entries found in the ResourceBlocks array within the Links object for a resource zone have been added or removed.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the resource zone that has changed.



ResourceBlockInUse(String)

This message shall be used to indicate that the composition request contains a ResourceBlock that is unable to participate in more compositions due to restrictions specified in its CompositionStatus property. For example, the ResourceBlock has reached its composition limit specified by the MaxCompositions property.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the ResourceBlock that cannot be part of any new compositions.



NoResourceMatch(String)

This message shall be used to indicate that the service could not find a matching resource based on the given parameters.

Tuple Fields

0: String

This argument shall contain the schema name of the requested resource.



EmptyManifest

This message shall be used to indicate that the manifest contains no stanzas, or a stanza in the manifest contains no request.



IncompatibleZone

This message shall be used to indicate that not all referenced resource blocks are in the same resource zone.



ResourceBlockChanged(String)

This message shall be used to indicate that one or more properties of a ResourceBlock have changed. This message shall not be used for cases where a more specific message could be used in its place.

Tuple Fields

0: String

The value of this argument shall contain the value of the Id property of the ResourceBlock that has changed.