StorageDevice

Enum StorageDevice 

pub enum StorageDevice {
Show 33 variants VolumeOffine(String, String), DrivePredictiveFailure(String), DriveRemoved(String), ControllerPasswordAccepted(String), WriteCacheDataLoss(String), BatteryOK(String), ControllerPreviousError(String, String), ControllerPortDegraded(String, String), VolumeOfflineCleared(String, String), WriteCacheProtected(String), BatteryCharging(String), DrivePredictiveFailureCleared(String), DriveOfflineCleared(String), DriveInserted(String), BatteryFailure(String), ControllerFailure(String), VolumeDegraded(String, String), DriveMissing(String), WriteCacheDegraded(String), ControllerOK(String), DriveMissingCleared(String), DriveOK(String), DriveOffline(String), VolumeOK(String, String), BatteryMissing(String), DriveFailureCleared(String), ControllerPortFailure(String), ControllerPortOK(String), VolumeFailure(String, String), WriteCacheTemporarilyDegraded(String), ControllerDegraded(String, String), ControllerPasswordRequired(String), DriveFailure(String),
}
This registry defines the messages for storage devices.

Variants



VolumeOffine(String, String)

This message shall be used to indicate a volume offline condition was detected. This may occur if the volume configuration is not supported or needs to be imported.

Tuple Fields

0: String

The value of this argument shall be a string containing an identifier for the volume. The identifier may contain Id, Name, Identifiers, LogicalUnitNumber, or other data used to uniquely identify the volume.

1: String

The value of this argument shall be a string containing the storage controller location.



DrivePredictiveFailure(String)

This message shall be used to indicate a drive predictive failure condition has been detected.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



DriveRemoved(String)

This message shall be used to indicate a drive has been removed.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



ControllerPasswordAccepted(String)

This message shall be used to indicate that the storage controller password was accepted. Normally this is used by storage controllers that require a controller password during boot to unlock encrypted volumes or drives.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



WriteCacheDataLoss(String)

This message shall be used to indicate the write cache is reporting loss of data in posted-writes cache memory due to loss of battery power when the server lost power or a hardware error.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



BatteryOK(String)

This message shall be used to indicate a battery health has changed to OK.

Tuple Fields

0: String

The value of this argument shall be a string containing the battery location.



ControllerPreviousError(String, String)

This message shall be used to indicate that an unreported storage controller error condition has been detected prior to reboot.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.

1: String

The value of this argument shall be a string containing the reason for failure.



ControllerPortDegraded(String, String)

This message shall be used to indicate a controller port degraded condition has been detected.

Tuple Fields

0: String

The value of this argument shall be a string containing the controller port location.

1: String

The value of this argument shall be a string containing the reason for the degraded controller port.



VolumeOfflineCleared(String, String)

This message shall be used to indicate a volume online condition was detected.

Tuple Fields

0: String

The value of this argument shall be a string containing an identifier for the volume. The identifier may contain Id, Name, Identifiers, LogicalUnitNumber, or other data used to uniquely identify the volume.

1: String

The value of this argument shall be a string containing the storage controller location.



WriteCacheProtected(String)

This message shall be used to indicate a controller write cache state is in protected mode.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



BatteryCharging(String)

This message shall be used to indicate a battery is below the required capacity and is charging.

Tuple Fields

0: String

The value of this argument shall be a string containing the battery location.



DrivePredictiveFailureCleared(String)

This message shall be used to indicate a predictive failure condition on a drive has been cleared, but any other failure conditions remain.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



DriveOfflineCleared(String)

This message shall be used to indicate a drive offline condition has been cleared.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



DriveInserted(String)

This message shall be used to indicate a drive has been inserted.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



BatteryFailure(String)

This message shall be used to indicate a battery failure condition has been detected.

Tuple Fields

0: String

The value of this argument shall be a string containing the battery location.



ControllerFailure(String)

This message shall be used to indicate that a storage controller failure condition has been detected due to a hardware, communication, or firmware failure.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



VolumeDegraded(String, String)

This message shall be used to indicate a volume degraded condition was detected due to one or more drives not installed correctly, missing, or has failed.

Tuple Fields

0: String

The value of this argument shall be a string containing an identifier for the volume. The identifier may contain Id, Name, Identifiers, LogicalUnitNumber, or other data used to uniquely identify the volume.

1: String

The value of this argument shall be a string containing the storage controller location.



DriveMissing(String)

This message shall be used to indicate a drive that is required by the configuration is missing. This message shall exist any time a volume is degraded or failed due to a missing drive.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



WriteCacheDegraded(String)

This message shall be used to indicate the write cache state degraded due to a missing battery or hardware failure.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



ControllerOK(String)

This message shall be used to indicate that the storage controller health has changed to OK.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



DriveMissingCleared(String)

This message shall be used to indicate a previous drive missing condition has been cleared.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



DriveOK(String)

This message shall be used to indicate a drive health has changed to OK.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



DriveOffline(String)

This message shall be used to indicate a drive offline condition has been detected. This may occur when a drive is unconfigured, encrypted by a foreign controller, offline during a background operation, or unsupported.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



VolumeOK(String, String)

This message shall be used to indicate a volume health has changed to OK.

Tuple Fields

0: String

The value of this argument shall be a string containing an identifier for the volume. The identifier may contain Id, Name, Identifiers, LogicalUnitNumber, or other data used to uniquely identify the volume.

1: String

The value of this argument shall be a string containing the storage controller location.



BatteryMissing(String)

This message shall be used to indicate a battery that is required by the configuration is missing.

Tuple Fields

0: String

The value of this argument shall be a string containing the battery location.



DriveFailureCleared(String)

This message shall be used to indicate a failure condition on a drive has been cleared, but any predictive failure or other conditions remain.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.



ControllerPortFailure(String)

This message shall be used to indicate a controller port failure condition has been detected.

Tuple Fields

0: String

The value of this argument shall be a string containing the controller port location.



ControllerPortOK(String)

This message shall be used to indicate a controller port health has changed to OK.

Tuple Fields

0: String

The value of this argument shall be a string containing the controller port location.



VolumeFailure(String, String)

This message shall be used to indicate a volume failure condition was detected due to one or more drives not installed correctly, missing, or has failed.

Tuple Fields

0: String

The value of this argument shall be a string containing an identifier for the volume. The identifier may contain Id, Name, Identifiers, LogicalUnitNumber, or other data used to uniquely identify the volume.

1: String

The value of this argument shall be a string containing the storage controller location.



WriteCacheTemporarilyDegraded(String)

This message shall be used to indicate write cache state temporarily degraded due to battery charging or data recovery rebuild operation pending.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



ControllerDegraded(String, String)

This message shall be used to indicate that a storage controller degraded condition has been detected.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.

1: String

The value of this argument shall be a string containing the reason for the degraded controller.



ControllerPasswordRequired(String)

This message shall be used to indicate that the storage controller requires a password. Normally this is used by storage controllers that require a controller password during boot to unlock encrypted volumes or drives.

Tuple Fields

0: String

The value of this argument shall be a string containing the storage controller location.



DriveFailure(String)

This message shall be used to indicate a drive failure condition detected due to a drive not installed correctly or has failed.

Tuple Fields

0: String

The value of this argument shall be a string containing the drive location.