pub enum TaskEvent {
TaskStarted(String),
TaskAborted(String),
TaskCompletedOK(String),
TaskPaused(String),
TaskCancelled(String),
TaskCompletedWarning(String),
TaskRemoved(String),
TaskResumed(String),
TaskProgressChanged(String, f64),
}Expand description
This registry defines the messages for task related events.
Variants
TaskStarted(String)
This message shall be used to indicate that a task has started as the TaskState property transitions to Starting or Running.
Tuple Fields
TaskAborted(String)
This message shall be used to indicate that a task has completed with errors and the TaskState property transitioned to Exception.
Tuple Fields
TaskCompletedOK(String)
This message shall be used to indicate that a task has completed and the TaskState property transitioned to Completed.
Tuple Fields
TaskPaused(String)
This message shall be used to indicate that a task has been paused and the TaskState property transitioned to Suspended or Interrupted.
Tuple Fields
TaskCancelled(String)
This message shall be used to indicate that work on a task has halted prior to completion due to an explicit request. The TaskState property transitioned to Cancelled.
Tuple Fields
TaskCompletedWarning(String)
This message shall be used to indicate that a task has completed with warnings and the TaskState property transitioned to Completed.
Tuple Fields
TaskRemoved(String)
This message shall be used to indicate that a task has been removed.
Tuple Fields
TaskResumed(String)
This message shall be used to indicate that a task has resumed and the TaskState property transitioned to Running from Suspended or Interrupted.
Tuple Fields
TaskProgressChanged(String, f64)
This message shall be used to indicate that a task has changed progress.