pub struct Cable {Show 30 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub assembly: Option<IdRef>,
pub asset_tag: Option<String>,
pub cable_class: Option<CableClass>,
pub cable_status: Option<CableStatus>,
pub cable_type: Option<String>,
pub description: Option<Description>,
pub downstream_connector_types: Option<Vec<ConnectorType>>,
pub downstream_name: Option<String>,
pub id: Id,
pub length_meters: Option<f64>,
pub links: Option<Links>,
pub location: Option<Location>,
pub manufacturer: Option<String>,
pub model: Option<String>,
pub name: Name,
pub oem: Option<Oem>,
pub part_number: Option<String>,
pub sku: Option<String>,
pub serial_number: Option<String>,
pub status: Option<Status>,
pub upstream_connector_types: Option<Vec<ConnectorType>>,
pub upstream_name: Option<String>,
pub user_description: Option<String>,
pub user_label: Option<String>,
pub vendor: Option<String>,
}Expand description
The Cable schema contains properties that describe a cable connecting endpoints of a chassis, port, or any other cable-compatible endpoint.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>assembly: Option<IdRef>asset_tag: Option<String>The user-assigned asset tag for this cable.
cable_class: Option<CableClass>cable_status: Option<CableStatus>cable_type: Option<String>The type of this cable.
description: Option<Description>downstream_connector_types: Option<Vec<ConnectorType>>The connector types this cable supports.
downstream_name: Option<String>The identifier for the downstream resource.
id: Idlength_meters: Option<f64>The length of the cable in meters.
links: Option<Links>location: Option<Location>manufacturer: Option<String>The manufacturer of this cable.
model: Option<String>The model number of the cable.
name: Nameoem: Option<Oem>part_number: Option<String>The part number for this cable.
sku: Option<String>The SKU for this cable.
serial_number: Option<String>The serial number for this cable.
status: Option<Status>upstream_connector_types: Option<Vec<ConnectorType>>The connector types this cable supports.
upstream_name: Option<String>The identifier for the downstream resource.
user_description: Option<String>The description of this cable.
user_label: Option<String>A user-assigned label.
vendor: Option<String>The manufacturer of this cable.