pub struct CoolingUnit {Show 34 fields
pub odata_context: Option<Context>,
pub odata_etag: Option<Etag>,
pub odata_id: Id,
pub odata_type: Type,
pub actions: Option<Actions>,
pub assembly: Option<IdRef>,
pub asset_tag: Option<String>,
pub coolant: Option<Coolant>,
pub cooling_capacity_watts: Option<i64>,
pub description: Option<Description>,
pub environment_metrics: Option<IdRef>,
pub equipment_type: CoolingEquipmentType,
pub filter_redundancy: Option<Vec<RedundantGroup>>,
pub filters: Option<IdRef>,
pub firmware_version: Option<String>,
pub id: Id,
pub leak_detection: Option<IdRef>,
pub links: Option<Links>,
pub location: Option<Location>,
pub manufacturer: Option<String>,
pub model: Option<String>,
pub name: Name,
pub oem: Option<Oem>,
pub part_number: Option<String>,
pub primary_coolant_connectors: Option<IdRef>,
pub production_date: Option<String>,
pub pump_redundancy: Option<Vec<RedundantGroup>>,
pub pumps: Option<IdRef>,
pub reservoirs: Option<IdRef>,
pub secondary_coolant_connectors: Option<IdRef>,
pub serial_number: Option<String>,
pub status: Option<Status>,
pub user_label: Option<String>,
pub version: Option<String>,
}Expand description
This is the schema definition for a cooling distribution component or unit, such as a cooling distribution unit (CDU) or a heat exchanger.
Fields
odata_context: Option<Context>odata_etag: Option<Etag>odata_id: Idodata_type: Typeactions: Option<Actions>assembly: Option<IdRef>asset_tag: Option<String>The user-assigned asset tag for this equipment.
coolant: Option<Coolant>cooling_capacity_watts: Option<i64>The cooling capacity (W) of this equipment.
description: Option<Description>environment_metrics: Option<IdRef>equipment_type: CoolingEquipmentTypefilter_redundancy: Option<Vec<RedundantGroup>>The redundancy information for the groups of filters in this unit.
filters: Option<IdRef>firmware_version: Option<String>The firmware version of this equipment.
id: Idleak_detection: Option<IdRef>links: Option<Links>location: Option<Location>manufacturer: Option<String>The manufacturer of this equipment.
model: Option<String>The product model number of this equipment.
name: Nameoem: Option<Oem>part_number: Option<String>The part number for this equipment.
primary_coolant_connectors: Option<IdRef>production_date: Option<String>The production or manufacturing date of this equipment.
pump_redundancy: Option<Vec<RedundantGroup>>The redundancy information for the groups of pumps in this unit.
pumps: Option<IdRef>reservoirs: Option<IdRef>secondary_coolant_connectors: Option<IdRef>serial_number: Option<String>The serial number for this equipment.
status: Option<Status>user_label: Option<String>A user-assigned label.
version: Option<String>The hardware version of this equipment.