pub struct BaseSpeedPrioritySettings {
pub base_speed_m_hz: Option<i64>,
pub core_count: Option<i64>,
pub core_i_ds: Option<Vec<i64>>,
}Expand description
The clock speed for a set of cores.
Fields
base_speed_m_hz: Option<i64>The clock speed to configure the set of cores in MHz.
core_count: Option<i64>The number of cores to configure with a specified speed.
core_i_ds: Option<Vec<i64>>The identifier of the cores to configure with the specified speed.