Structs
- Actions
- The available actions for this resource.
- Composition
Status - Composition status of the resource block.
- Links
- The links to other resources that are related to this resource.
- OemActions
- The available OEM-specific actions for this resource.
- Resource
Block - The ResourceBlock schema contains definitions resource blocks, its components, and affinity to composed devices.