This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
This action is used to establish a replication relationship by assigning an existing volume to serve as a target replica for an existing source volume.
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
This action is used to create a new volume resource to provide expanded data protection through a replica relationship with the specified source volume.
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
This action is used to prepare the contents of the volume for use by the system. If InitializeMethod is not specified in the request body, but the property InitializeMethod is specified, the property InitializeMethod value should be used. If neither is specified, the InitializeMethod should be Foreground.
This action is used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
This action is used to disable data synchronization between a source and target volume, remove the replication relationship, and optionally delete the target volume.
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action is used to resume the active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.
This action is used to suspend active data synchronization between a source and target volume, without otherwise altering the replication relationship.