pub enum Composition {
Show 13 variants
ResourceBlockCompositionStateChanged(String),
ResourceBlockNotFound(String),
ResourceBlockInvalid(String),
ConstrainedResourceAlreadyReserved(String),
ResourceBlockStateChanged(String),
SpecifiedResourceAlreadyReserved(String, String),
UnableToProcessStanzaRequest(String, String),
ResourceZoneMembershipChanged(String),
ResourceBlockInUse(String),
NoResourceMatch(String),
EmptyManifest,
IncompatibleZone,
ResourceBlockChanged(String),
}Expand description
This registry defines the messages for composition related events
Variants
ResourceBlockCompositionStateChanged(String)
This message shall be used to indicate that the CompositionState property within the CompositionStatus object of a ResourceBlock has changed.
Tuple Fields
ResourceBlockNotFound(String)
This message shall be used to indicate that the referenced resource block is not found.
Tuple Fields
ResourceBlockInvalid(String)
This message shall be used to indicate that the Id of a referenced resource block is no longer valid.
Tuple Fields
ConstrainedResourceAlreadyReserved(String)
This message shall be used to indicate that the requested resources are already reserved in response to a constrained composition request.
Tuple Fields
ResourceBlockStateChanged(String)
This message shall be used to indicate that the State property within the Status object of a ResourceBlock has changed.
Tuple Fields
SpecifiedResourceAlreadyReserved(String, String)
This message shall be used to indicate that a resource block is already reserved in response to a specific composition request.
Tuple Fields
UnableToProcessStanzaRequest(String, String)
This message shall be used to indicate that the manifest provided for the Compose action contains a stanza with Content that could not be processed.
Tuple Fields
ResourceZoneMembershipChanged(String)
This message shall be used to indicate that entries found in the ResourceBlocks array within the Links object for a resource zone have been added or removed.
Tuple Fields
ResourceBlockInUse(String)
This message shall be used to indicate that the composition request contains a ResourceBlock that is unable to participate in more compositions due to restrictions specified in its CompositionStatus property. For example, the ResourceBlock has reached its composition limit specified by the MaxCompositions property.
Tuple Fields
NoResourceMatch(String)
This message shall be used to indicate that the service could not find a matching resource based on the given parameters.
EmptyManifest
This message shall be used to indicate that the manifest contains no stanzas, or a stanza in the manifest contains no request.
IncompatibleZone
This message shall be used to indicate that not all referenced resource blocks are in the same resource zone.
ResourceBlockChanged(String)
This message shall be used to indicate that one or more properties of a ResourceBlock have changed. This message shall not be used for cases where a more specific message could be used in its place.