pub enum NetworkDevice {
CableInserted(String, String),
DegradedConnectionEstablished(String, String, String),
LinkFlapDetected(String, String, String, f64, f64),
CableRemoved(String, String),
ConnectionDropped(String, String, String),
ConnectionEstablished(String, String, String),
}Expand description
This registry defines the messages for networking devices
Variants
CableInserted(String, String)
This message shall be used to indicate that a network cable has been inserted. This message shall not be sent for a backplane connection.
Tuple Fields
DegradedConnectionEstablished(String, String, String)
This message shall be used to indicate that a network connection is newly established, but that the link speed is lower than provisioned for the channel.
Tuple Fields
0: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network adapter to which a connection has been established.
LinkFlapDetected(String, String, String, f64, f64)
This message shall be used to indicate that a network connection has repeatedly been established and dropped. This message shall not be repeated more than once in any 24 hour period.
Tuple Fields
0: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network adapter to which a connection has been established.
1: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network port to which a connection has been established.
2: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network device function to which a connection has been established.
CableRemoved(String, String)
This message shall be used to indicate that a network cable has been removed. This message shall not be sent for a backplane connection.
Tuple Fields
ConnectionDropped(String, String, String)
This message shall be used to indicate that the link for a network connection is no longer intact.
Tuple Fields
0: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network adapter from which a connection has dropped.
ConnectionEstablished(String, String, String)
This message shall be used to indicate that the link for a network connection is newly established.
Tuple Fields
0: StringThe value of this argument shall contain a string that identifies or describes the location or physical context of the network adapter to which a connection has been established.