pub enum SensorEvent {
Show 17 variants
ReadingAboveLowerFatalThreshold(String, f64, String, f64),
ReadingAboveUpperFatalThreshold(String, f64, String, f64),
ReadingCritical(String, f64, String),
SensorFailure(String),
ReadingBelowLowerCautionThreshold(String, f64, String, f64),
ReadingBelowLowerFatalThreshold(String, f64, String, f64),
ReadingBelowUpperCriticalThreshold(String, f64, String, f64),
ReadingNoLongerCritical(String, f64, String),
ReadingBelowLowerCriticalThreshold(String, f64, String, f64),
ReadingWarning(String, f64, String),
ReadingAboveUpperCautionThreshold(String, f64, String, f64),
ReadingBelowUpperFatalThreshold(String, f64, String, f64),
SensorRestored(String),
ReadingAboveUpperCriticalThreshold(String, f64, String, f64),
InvalidSensorReading(String),
ReadingAboveLowerCriticalThreshold(String, f64, String, f64),
SensorReadingNormalRange(String, f64, String),
}Expand description
This registry defines messages used for general events related to Sensor resources.
Variants
ReadingAboveLowerFatalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading in a Sensor resource, previously below the threshold, is now above the value of the Reading property within the LowerFatal property. However, the value of the Reading property is still below at least one Reading property of another lower threshold and is not within the normal operating range.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingAboveUpperFatalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is above the value of the Reading property within the UpperFatal property.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingCritical(String, f64, String)
This message shall be used to indicate that the value of the Reading property in a Sensor resource exceeds the value of an internal critical level. This message shall be used for Sensor resources that do not contain readable critical threshold values, such as boolean trip points or similiar hardware mechanisms. This message shall not be used if the Reading property within a corresponding critical threshold is available.
Tuple Fields
SensorFailure(String)
This message shall be used to indicate that the service is unable to communicate with a sensor or has otherwise detected a fault condition with the sensor.
Tuple Fields
ReadingBelowLowerCautionThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is below the value of the Reading property within the LowerCaution or LowerCautionUser properties.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingBelowLowerFatalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is below the value of the Reading property within the LowerFatal property.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingBelowUpperCriticalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading in a Sensor resource, previously above the threshold, is now below the value of the Reading property within the UpperCritical or UpperCriticalUser properties. However, the value of the Reading property is still above at least one Reading property of another upper threshold and is not within the normal operating range.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingNoLongerCritical(String, f64, String)
This message shall be used to indicate that the value of the Reading property in a Sensor resource no longer exceeds the value of an internal critical level, but the value still exceeds an internal warning level. This message shall be used for Sensor resources that do not contain readable critical threshold values, such as boolean trip points or similiar hardware mechanisms. This message shall not be used if the Reading property within a corresponding critical threshold is available.
Tuple Fields
ReadingBelowLowerCriticalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is below the value of the Reading property within the LowerCritical or LowerCriticalUser properties.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingWarning(String, f64, String)
This message shall be used to indicate that the value of the Reading property in a Sensor resource exceeds the value of an internal warning level. This message shall be used for Sensor resources that do not contain readable caution threshold values, such as boolean trip points or similiar hardware mechanisms. This message shall not be used if the Reading property within a corresponding caution threshold is available.
Tuple Fields
ReadingAboveUpperCautionThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is above the value of the Reading property within the UpperCaution or UpperCautionUser properties.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
ReadingBelowUpperFatalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading in a Sensor resource, previously above the threshold, is now below the value of the Reading property within the UpperFatal property. However, the value of the Reading property is still above at least one Reading property of another upper threshold and is not within the normal operating range.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
SensorRestored(String)
This message shall be used to indicate that the service is able to communicate with a sensor that had previously failed, or the sensor has been repaired or replaced.
Tuple Fields
ReadingAboveUpperCriticalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading property in a Sensor resource is above the value of the Reading property within the UpperCritical or UpperCriticalUser properties.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
InvalidSensorReading(String)
This message shall be used to indicate that the service received invalid data while attempting to update the value of the Reading property in a Sensor resource.
Tuple Fields
ReadingAboveLowerCriticalThreshold(String, f64, String, f64)
This message shall be used to indicate that the value of the Reading in a Sensor resource, previously below the threshold, is now above the value of the Reading property within the LowerCritical or LowerCriticalUser properties. However, the value of the Reading property is still below at least one Reading property of another lower threshold and is not within the normal operating range.
Tuple Fields
1: f64This argument shall contain a number that equals the value of the Reading property of the Sensor resource.
SensorReadingNormalRange(String, f64, String)
This message shall be used to indicate that the value of the Reading property within a Sensor resource has returned to its normal operating range.